@@ -20,6 +20,7 @@ return [
         'am' => 'الأمهرية',
         'an' => 'الأراغونية',
         'ang' => 'الإنجليزية القديمة',
+        'ann' => 'أوبلو',
         'anp' => 'الأنجيكا',
         'ar' => 'العربية',
         'arc' => 'الآرامية',
@@ -30,6 +31,7 @@ return [
         'as' => 'الأسامية',
         'asa' => 'الآسو',
         'ast' => 'الأسترية',
+        'atj' => 'الأتيكاميكو',
         'av' => 'الأوارية',
         'awa' => 'الأوادية',
         'ay' => 'الأيمارا',
@@ -86,13 +88,21 @@ return [
         'chr' => 'الشيروكي',
         'chy' => 'الشايان',
         'ckb' => 'السورانية الكردية',
+        'clc' => 'تسيلكوتين',
         'co' => 'الكورسيكية',
         'cop' => 'القبطية',
         'cr' => 'الكرى',
+        'crg' => 'الميتشيف',
         'crh' => 'لغة تتار القرم',
+        'crj' => 'الكري الجنوب شرقية',
+        'crk' => 'البلينز-كري',
+        'crl' => 'الكري شمال الشرقية',
+        'crm' => 'الموس-كري',
+        'crr' => 'الألغونكوية كارولينا',
         'crs' => 'الفرنسية الكريولية السيشيلية',
         'cs' => 'التشيكية',
         'csb' => 'الكاشبايان',
+        'csw' => 'السوامبي-كري',
         'cu' => 'سلافية كنسية',
         'cv' => 'التشوفاشي',
         'cy' => 'الويلزية',
@@ -173,6 +183,7 @@ return [
         'hai' => 'الهيدا',
         'hak' => 'الهاكا الصينية',
         'haw' => 'لغة هاواي',
+        'hax' => 'هايدا الجنوبية',
         'he' => 'العبرية',
         'hi' => 'الهندية',
         'hil' => 'الهيليجينون',
@@ -185,6 +196,7 @@ return [
         'ht' => 'الكريولية الهايتية',
         'hu' => 'الهنغارية',
         'hup' => 'الهبا',
+        'hur' => 'الهالكوميليم',
         'hy' => 'الأرمنية',
         'hz' => 'الهيريرو',
         'ia' => 'اللّغة الوسيطة',
@@ -195,6 +207,7 @@ return [
         'ig' => 'الإيجبو',
         'ii' => 'السيتشيون يي',
         'ik' => 'الإينبياك',
+        'ikt' => 'الإنكتيتوتية الكندية الغربية',
         'ilo' => 'الإيلوكو',
         'inh' => 'الإنجوشية',
         'io' => 'الإيدو',
@@ -222,6 +235,7 @@ return [
         'kea' => 'كابوفيرديانو',
         'kfo' => 'الكورو',
         'kg' => 'الكونغو',
+        'kgp' => 'الكاينغانغ',
         'kha' => 'الكازية',
         'kho' => 'الخوتانيز',
         'khq' => 'كويرا تشيني',
@@ -252,6 +266,7 @@ return [
         'kut' => 'الكتيناي',
         'kv' => 'الكومي',
         'kw' => 'الكورنية',
+        'kwk' => 'الكواكوالا',
         'ky' => 'القيرغيزية',
         'la' => 'اللاتينية',
         'lad' => 'اللادينو',
@@ -262,6 +277,7 @@ return [
         'lez' => 'الليزجية',
         'lg' => 'الغاندا',
         'li' => 'الليمبورغية',
+        'lil' => 'الليلويتية',
         'lkt' => 'لاكوتا',
         'ln' => 'اللينجالا',
         'lo' => 'اللاوية',
@@ -269,6 +285,7 @@ return [
         'lou' => 'الكريولية اللويزيانية',
         'loz' => 'اللوزي',
         'lrc' => 'اللرية الشمالية',
+        'lsm' => 'الساميا',
         'lt' => 'الليتوانية',
         'lu' => 'اللوبا كاتانغا',
         'lua' => 'اللبا-لؤلؤ',
@@ -303,6 +320,7 @@ return [
         'mn' => 'المنغولية',
         'mnc' => 'المانشو',
         'mni' => 'المانيبورية',
+        'moe' => 'إينو-ايمون',
         'moh' => 'الموهوك',
         'mos' => 'الموسي',
         'mr' => 'الماراثية',
@@ -347,6 +365,11 @@ return [
         'nzi' => 'النزيما',
         'oc' => 'الأوكسيتانية',
         'oj' => 'الأوجيبوا',
+        'ojb' => 'أوجيبوا الشمالية الغربية',
+        'ojc' => 'أوجيبوا الوسطى',
+        'ojs' => 'الأوجي-كري',
+        'ojw' => 'الأوجيبوا الغربية',
+        'oka' => 'الأوكاناغانية',
         'om' => 'الأورومية',
         'or' => 'الأورية',
         'os' => 'الأوسيتيك',
@@ -362,8 +385,10 @@ return [
         'peo' => 'الفارسية القديمة',
         'phn' => 'الفينيقية',
         'pi' => 'البالية',
+        'pis' => 'بيجين',
         'pl' => 'البولندية',
         'pon' => 'البوهنبيايان',
+        'pqm' => 'الماليزيت-باساماكودي',
         'prg' => 'البروسياوية',
         'pro' => 'البروفانسية القديمة',
         'ps' => 'البشتو',
@@ -412,6 +437,7 @@ return [
         'sid' => 'السيدامو',
         'sk' => 'السلوفاكية',
         'sl' => 'السلوفانية',
+        'slh' => 'لوشوتسيد الجنوبية',
         'sm' => 'الساموائية',
         'sma' => 'السامي الجنوبي',
         'smj' => 'اللول سامي',
@@ -428,6 +454,7 @@ return [
         'ss' => 'السواتي',
         'ssy' => 'لغة الساهو',
         'st' => 'السوتو الجنوبية',
+        'str' => 'سترايتس ساليش',
         'su' => 'السوندانية',
         'suk' => 'السوكوما',
         'sus' => 'السوسو',
@@ -438,13 +465,16 @@ return [
         'syc' => 'سريانية تقليدية',
         'syr' => 'السريانية',
         'ta' => 'التاميلية',
+        'tce' => 'التوتشون الجنوبية',
         'te' => 'التيلوغوية',
         'tem' => 'التيمن',
         'teo' => 'تيسو',
         'ter' => 'التيرينو',
         'tet' => 'التيتم',
         'tg' => 'الطاجيكية',
+        'tgx' => 'التاغيش',
         'th' => 'التايلاندية',
+        'tht' => 'التالتان',
         'ti' => 'التغرينية',
         'tig' => 'التيغرية',
         'tiv' => 'التيف',
@@ -457,12 +487,14 @@ return [
         'tn' => 'التسوانية',
         'to' => 'التونغية',
         'tog' => 'تونجا - نياسا',
+        'tok' => 'التوكي-بونا',
         'tpi' => 'التوك بيسين',
         'tr' => 'التركية',
         'trv' => 'لغة التاروكو',
         'ts' => 'السونجا',
         'tsi' => 'التسيمشيان',
         'tt' => 'التترية',
+        'ttm' => 'التوتشون الشمالية',
         'tum' => 'التامبوكا',
         'tvl' => 'التوفالو',
         'tw' => 'التوي',
@@ -500,6 +532,7 @@ return [
         'ybb' => 'يمبا',
         'yi' => 'اليديشية',
         'yo' => 'اليوروبا',
+        'yrl' => 'النيينجاتو',
         'yue' => 'الكَنْتُونية',
         'za' => 'الزهيونج',
         'zap' => 'الزابوتيك',
