@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'Chechen (Russia)',
         'cs' => 'Czech',
         'cs_CZ' => 'Czech (Czechia)',
+        'cv' => 'Chuvash',
+        'cv_RU' => 'Chuvash (Russia)',
         'cy' => 'Welsh',
         'cy_GB' => 'Welsh (United Kingdom)',
         'da' => 'Danish',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'English (Montserrat)',
         'en_MT' => 'English (Malta)',
         'en_MU' => 'English (Mauritius)',
+        'en_MV' => 'English (Maldives)',
         'en_MW' => 'English (Malawi)',
         'en_MY' => 'English (Malaysia)',
         'en_NA' => 'English (Namibia)',
@@ -237,37 +240,37 @@ return [
         'fa' => 'Persian',
         'fa_AF' => 'Persian (Afghanistan)',
         'fa_IR' => 'Persian (Iran)',
-        'ff' => 'Fulah',
-        'ff_Adlm' => 'Fulah (Adlam)',
-        'ff_Adlm_BF' => 'Fulah (Adlam, Burkina Faso)',
-        'ff_Adlm_CM' => 'Fulah (Adlam, Cameroon)',
-        'ff_Adlm_GH' => 'Fulah (Adlam, Ghana)',
-        'ff_Adlm_GM' => 'Fulah (Adlam, Gambia)',
-        'ff_Adlm_GN' => 'Fulah (Adlam, Guinea)',
-        'ff_Adlm_GW' => 'Fulah (Adlam, Guinea-Bissau)',
-        'ff_Adlm_LR' => 'Fulah (Adlam, Liberia)',
-        'ff_Adlm_MR' => 'Fulah (Adlam, Mauritania)',
-        'ff_Adlm_NE' => 'Fulah (Adlam, Niger)',
-        'ff_Adlm_NG' => 'Fulah (Adlam, Nigeria)',
-        'ff_Adlm_SL' => 'Fulah (Adlam, Sierra Leone)',
-        'ff_Adlm_SN' => 'Fulah (Adlam, Senegal)',
-        'ff_CM' => 'Fulah (Cameroon)',
-        'ff_GN' => 'Fulah (Guinea)',
-        'ff_Latn' => 'Fulah (Latin)',
-        'ff_Latn_BF' => 'Fulah (Latin, Burkina Faso)',
-        'ff_Latn_CM' => 'Fulah (Latin, Cameroon)',
-        'ff_Latn_GH' => 'Fulah (Latin, Ghana)',
-        'ff_Latn_GM' => 'Fulah (Latin, Gambia)',
-        'ff_Latn_GN' => 'Fulah (Latin, Guinea)',
-        'ff_Latn_GW' => 'Fulah (Latin, Guinea-Bissau)',
-        'ff_Latn_LR' => 'Fulah (Latin, Liberia)',
-        'ff_Latn_MR' => 'Fulah (Latin, Mauritania)',
-        'ff_Latn_NE' => 'Fulah (Latin, Niger)',
-        'ff_Latn_NG' => 'Fulah (Latin, Nigeria)',
-        'ff_Latn_SL' => 'Fulah (Latin, Sierra Leone)',
-        'ff_Latn_SN' => 'Fulah (Latin, Senegal)',
-        'ff_MR' => 'Fulah (Mauritania)',
-        'ff_SN' => 'Fulah (Senegal)',
+        'ff' => 'Fula',
+        'ff_Adlm' => 'Fula (Adlam)',
+        'ff_Adlm_BF' => 'Fula (Adlam, Burkina Faso)',
+        'ff_Adlm_CM' => 'Fula (Adlam, Cameroon)',
+        'ff_Adlm_GH' => 'Fula (Adlam, Ghana)',
+        'ff_Adlm_GM' => 'Fula (Adlam, Gambia)',
+        'ff_Adlm_GN' => 'Fula (Adlam, Guinea)',
+        'ff_Adlm_GW' => 'Fula (Adlam, Guinea-Bissau)',
+        'ff_Adlm_LR' => 'Fula (Adlam, Liberia)',
+        'ff_Adlm_MR' => 'Fula (Adlam, Mauritania)',
+        'ff_Adlm_NE' => 'Fula (Adlam, Niger)',
+        'ff_Adlm_NG' => 'Fula (Adlam, Nigeria)',
+        'ff_Adlm_SL' => 'Fula (Adlam, Sierra Leone)',
+        'ff_Adlm_SN' => 'Fula (Adlam, Senegal)',
+        'ff_CM' => 'Fula (Cameroon)',
+        'ff_GN' => 'Fula (Guinea)',
+        'ff_Latn' => 'Fula (Latin)',
+        'ff_Latn_BF' => 'Fula (Latin, Burkina Faso)',
+        'ff_Latn_CM' => 'Fula (Latin, Cameroon)',
+        'ff_Latn_GH' => 'Fula (Latin, Ghana)',
+        'ff_Latn_GM' => 'Fula (Latin, Gambia)',
+        'ff_Latn_GN' => 'Fula (Latin, Guinea)',
+        'ff_Latn_GW' => 'Fula (Latin, Guinea-Bissau)',
+        'ff_Latn_LR' => 'Fula (Latin, Liberia)',
+        'ff_Latn_MR' => 'Fula (Latin, Mauritania)',
+        'ff_Latn_NE' => 'Fula (Latin, Niger)',
+        'ff_Latn_NG' => 'Fula (Latin, Nigeria)',
+        'ff_Latn_SL' => 'Fula (Latin, Sierra Leone)',
+        'ff_Latn_SN' => 'Fula (Latin, Senegal)',
+        'ff_MR' => 'Fula (Mauritania)',
+        'ff_SN' => 'Fula (Senegal)',
         'fi' => 'Finnish',
         'fi_FI' => 'Finnish (Finland)',
         'fo' => 'Faroese',
@@ -341,6 +344,8 @@ return [
         'he_IL' => 'Hebrew (Israel)',
         'hi' => 'Hindi',
         'hi_IN' => 'Hindi (India)',
+        'hi_Latn' => 'Hindi (Latin)',
+        'hi_Latn_IN' => 'Hindi (Latin, India)',
         'hr' => 'Croatian',
         'hr_BA' => 'Croatian (Bosnia & Herzegovina)',
         'hr_HR' => 'Croatian (Croatia)',
@@ -385,6 +390,8 @@ return [
         'ks' => 'Kashmiri',
         'ks_Arab' => 'Kashmiri (Arabic)',
         'ks_Arab_IN' => 'Kashmiri (Arabic, India)',
+        'ks_Deva' => 'Kashmiri (Devanagari)',
+        'ks_Deva_IN' => 'Kashmiri (Devanagari, India)',
         'ks_IN' => 'Kashmiri (India)',
         'ku' => 'Kurdish',
         'ku_TR' => 'Kurdish (Turkey)',
@@ -512,6 +519,7 @@ return [
         'sd_Arab_PK' => 'Sindhi (Arabic, Pakistan)',
         'sd_Deva' => 'Sindhi (Devanagari)',
         'sd_Deva_IN' => 'Sindhi (Devanagari, India)',
+        'sd_IN' => 'Sindhi (India)',
         'sd_PK' => 'Sindhi (Pakistan)',
         'se' => 'Northern Sami',
         'se_FI' => 'Northern Sami (Finland)',
