@@ -75,6 +75,8 @@ return [
         'ce_RU' => 'चेचेन (रशिया)',
         'cs' => 'झेक',
         'cs_CZ' => 'झेक (झेकिया)',
+        'cv' => 'चूवाश',
+        'cv_RU' => 'चूवाश (रशिया)',
         'cy' => 'वेल्श',
         'cy_GB' => 'वेल्श (युनायटेड किंगडम)',
         'da' => 'डॅनिश',
@@ -157,6 +159,7 @@ return [
         'en_MS' => 'इंग्रजी (मॉन्ट्सेराट)',
         'en_MT' => 'इंग्रजी (माल्टा)',
         'en_MU' => 'इंग्रजी (मॉरिशस)',
+        'en_MV' => 'इंग्रजी (मालदीव)',
         'en_MW' => 'इंग्रजी (मलावी)',
         'en_MY' => 'इंग्रजी (मलेशिया)',
         'en_NA' => 'इंग्रजी (नामिबिया)',
@@ -238,6 +241,19 @@ return [
         'fa_AF' => 'फारसी (अफगाणिस्तान)',
         'fa_IR' => 'फारसी (इराण)',
         'ff' => 'फुलाह',
+        'ff_Adlm' => 'फुलाह (अदलम)',
+        'ff_Adlm_BF' => 'फुलाह (अदलम, बुर्किना फासो)',
+        'ff_Adlm_CM' => 'फुलाह (अदलम, कॅमेरून)',
+        'ff_Adlm_GH' => 'फुलाह (अदलम, घाना)',
+        'ff_Adlm_GM' => 'फुलाह (अदलम, गाम्बिया)',
+        'ff_Adlm_GN' => 'फुलाह (अदलम, गिनी)',
+        'ff_Adlm_GW' => 'फुलाह (अदलम, गिनी-बिसाउ)',
+        'ff_Adlm_LR' => 'फुलाह (अदलम, लायबेरिया)',
+        'ff_Adlm_MR' => 'फुलाह (अदलम, मॉरिटानिया)',
+        'ff_Adlm_NE' => 'फुलाह (अदलम, नाइजर)',
+        'ff_Adlm_NG' => 'फुलाह (अदलम, नायजेरिया)',
+        'ff_Adlm_SL' => 'फुलाह (अदलम, सिएरा लिओन)',
+        'ff_Adlm_SN' => 'फुलाह (अदलम, सेनेगल)',
         'ff_CM' => 'फुलाह (कॅमेरून)',
         'ff_GN' => 'फुलाह (गिनी)',
         'ff_Latn' => 'फुलाह (लॅटिन)',
@@ -271,7 +287,7 @@ return [
         'fr_CF' => 'फ्रेंच (केंद्रीय अफ्रिकी प्रजासत्ताक)',
         'fr_CG' => 'फ्रेंच (काँगो - ब्राझाविले)',
         'fr_CH' => 'फ्रेंच (स्वित्झर्लंड)',
-        'fr_CI' => 'फ्रेंच (Côte d’Ivoire)',
+        'fr_CI' => 'फ्रेंच (कोत द’ईवोआर)',
         'fr_CM' => 'फ्रेंच (कॅमेरून)',
         'fr_DJ' => 'फ्रेंच (जिबौटी)',
         'fr_DZ' => 'फ्रेंच (अल्जीरिया)',
@@ -328,6 +344,8 @@ return [
         'he_IL' => 'हिब्रू (इस्त्राइल)',
         'hi' => 'हिंदी',
         'hi_IN' => 'हिंदी (भारत)',
+        'hi_Latn' => 'हिंदी (लॅटिन)',
+        'hi_Latn_IN' => 'हिंदी (लॅटिन, भारत)',
         'hr' => 'क्रोएशियन',
         'hr_BA' => 'क्रोएशियन (बोस्निया अणि हर्जेगोविना)',
         'hr_HR' => 'क्रोएशियन (क्रोएशिया)',
@@ -372,6 +390,8 @@ return [
         'ks' => 'काश्मीरी',
         'ks_Arab' => 'काश्मीरी (अरबी)',
         'ks_Arab_IN' => 'काश्मीरी (अरबी, भारत)',
+        'ks_Deva' => 'काश्मीरी (देवनागरी)',
+        'ks_Deva_IN' => 'काश्मीरी (देवनागरी, भारत)',
         'ks_IN' => 'काश्मीरी (भारत)',
         'ku' => 'कुर्दिश',
         'ku_TR' => 'कुर्दिश (तुर्की)',
@@ -499,6 +519,7 @@ return [
         'sd_Arab_PK' => 'सिंधी (अरबी, पाकिस्तान)',
         'sd_Deva' => 'सिंधी (देवनागरी)',
         'sd_Deva_IN' => 'सिंधी (देवनागरी, भारत)',
+        'sd_IN' => 'सिंधी (भारत)',
         'sd_PK' => 'सिंधी (पाकिस्तान)',
         'se' => 'उत्तरी सामी',
         'se_FI' => 'उत्तरी सामी (फिनलंड)',
