@@ -12,22 +12,20 @@
 namespace Symfony\Component\Messenger\Bridge\Doctrine\Tests\Transport;
 
 use Doctrine\DBAL\Abstraction\Result as AbstractionResult;
-use Doctrine\DBAL\Configuration;
 use Doctrine\DBAL\Connection as DBALConnection;
 use Doctrine\DBAL\Driver\Result as DriverResult;
 use Doctrine\DBAL\Driver\ResultStatement;
 use Doctrine\DBAL\Exception as DBALException;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Platforms\MySQL57Platform;
+use Doctrine\DBAL\Platforms\OraclePlatform;
 use Doctrine\DBAL\Platforms\SQLServer2012Platform;
 use Doctrine\DBAL\Query\QueryBuilder;
 use Doctrine\DBAL\Result;
 use Doctrine\DBAL\Schema\AbstractSchemaManager;
 use Doctrine\DBAL\Schema\Schema;
 use Doctrine\DBAL\Schema\SchemaConfig;
-use Doctrine\DBAL\Schema\TableDiff;
 use Doctrine\DBAL\Statement;
-use Doctrine\DBAL\Types\Types;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\Messenger\Bridge\Doctrine\Tests\Fixtures\DummyMessage;
 use Symfony\Component\Messenger\Bridge\Doctrine\Transport\Connection;
@@ -400,59 +398,10 @@ class ConnectionTest extends TestCase
             new SQLServer2012Platform(),
             'SELECT m.* FROM messenger_messages m WITH (UPDLOCK, ROWLOCK) WHERE (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) AND (m.queue_name = ?) ORDER BY available_at ASC OFFSET 0 ROWS FETCH NEXT 1 ROWS ONLY  ',
         ];
-    }
 
-    /**
-     * @dataProvider setupIndicesProvider
-     */
-    public function testSetupIndices(string $platformClass, array $expectedIndices)
-    {
-        $driverConnection = $this->createMock(DBALConnection::class);
-        $driverConnection->method('getConfiguration')->willReturn(new Configuration());
-
-        $schemaManager = $this->createMock(AbstractSchemaManager::class);
-        $schema = new Schema();
-        $expectedTable = $schema->createTable('messenger_messages');
-        $expectedTable->addColumn('id', Types::BIGINT);
-        $expectedTable->setPrimaryKey(['id']);
-        // Make sure columns for indices exists so addIndex() will not throw
-        foreach (array_unique(array_merge(...$expectedIndices)) as $columnName) {
-            $expectedTable->addColumn($columnName, Types::STRING);
-        }
-        foreach ($expectedIndices as $indexColumns) {
-            $expectedTable->addIndex($indexColumns);
-        }
-        $schemaManager->method('createSchema')->willReturn($schema);
-        if (method_exists(DBALConnection::class, 'createSchemaManager')) {
-            $driverConnection->method('createSchemaManager')->willReturn($schemaManager);
-        } else {
-            $driverConnection->method('getSchemaManager')->willReturn($schemaManager);
-        }
-
-        $platformMock = $this->createMock($platformClass);
-        $platformMock
-            ->expects(self::once())
-            ->method('getAlterTableSQL')
-            ->with(self::callback(static function (TableDiff $tableDiff): bool {
-                return 0 === \count($tableDiff->addedIndexes) && 0 === \count($tableDiff->changedIndexes) && 0 === \count($tableDiff->removedIndexes);
-            }))
-            ->willReturn([]);
-        $driverConnection->method('getDatabasePlatform')->willReturn($platformMock);
-
-        $connection = new Connection([], $driverConnection);
-        $connection->setup();
-    }
-
-    public function setupIndicesProvider(): iterable
-    {
-        yield 'MySQL' => [
-            MySQL57Platform::class,
-            [['delivered_at']],
-        ];
-
-        yield 'Other platforms' => [
-            AbstractPlatform::class,
-            [['queue_name'], ['available_at'], ['delivered_at']],
+        yield 'Oracle' => [
+            new OraclePlatform(),
+            'SELECT w.id AS "id", w.body AS "body", w.headers AS "headers", w.queue_name AS "queue_name", w.created_at AS "created_at", w.available_at AS "available_at", w.delivered_at AS "delivered_at" FROM messenger_messages w WHERE w.id IN(SELECT a.id FROM (SELECT m.* FROM messenger_messages m WHERE (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) AND (m.queue_name = ?) ORDER BY available_at ASC) a WHERE ROWNUM <= 1) FOR UPDATE',
         ];
     }
 
