@@ -26,7 +26,7 @@ class RedisArrayStoreTest extends AbstractRedisStoreTest
             throw new SkippedTestSuiteError('The RedisArray class is required.');
         }
         try {
-            (new \Redis())->connect(getenv('REDIS_HOST'));
+            (new \Redis())->connect(...explode(':', getenv('REDIS_HOST')));
         } catch (\Exception $e) {
             throw new SkippedTestSuiteError($e->getMessage());
         }
