@@ -15,6 +15,7 @@ use Psr\Log\LoggerInterface;
 use Symfony\Component\HttpClient\MockHttpClient;
 use Symfony\Component\HttpClient\Response\MockResponse;
 use Symfony\Component\Translation\Bridge\Lokalise\LokaliseProvider;
+use Symfony\Component\Translation\Exception\ProviderException;
 use Symfony\Component\Translation\Loader\ArrayLoader;
 use Symfony\Component\Translation\Loader\LoaderInterface;
 use Symfony\Component\Translation\Loader\XliffFileLoader;
@@ -247,6 +248,307 @@ class LokaliseProviderTest extends ProviderTestCase
         $this->assertTrue($updateProcessed, 'Translations update was not called.');
     }
 
+    public function testWriteGetLanguageServerError()
+    {
+        $getLanguagesResponse = function (string $method, string $url, array $options = []): ResponseInterface {
+            $this->assertSame('GET', $method);
+            $this->assertSame('https://api.lokalise.com/api2/projects/PROJECT_ID/languages', $url);
+
+            return new MockResponse('', ['http_code' => 500]);
+        };
+
+        $provider = $this->createProvider((new MockHttpClient([
+            $getLanguagesResponse,
+        ]))->withOptions([
+            'base_uri' => 'https://api.lokalise.com/api2/projects/PROJECT_ID/',
+            'headers' => ['X-Api-Token' => 'API_KEY'],
+        ]), $this->getLoader(), $this->getLogger(), $this->getDefaultLocale(), 'api.lokalise.com');
+
+        $translatorBag = new TranslatorBag();
+        $translatorBag->addCatalogue(new MessageCatalogue('en', [
+            'messages' => ['young_dog' => 'puppy'],
+        ]));
+
+        $this->expectException(ProviderException::class);
+        $this->expectExceptionMessage('Unable to get languages from Lokalise.');
+
+        $provider->write($translatorBag);
+    }
+
+    public function testWriteCreateLanguageServerError()
+    {
+        $getLanguagesResponse = function (string $method, string $url, array $options = []): ResponseInterface {
+            $this->assertSame('GET', $method);
+            $this->assertSame('https://api.lokalise.com/api2/projects/PROJECT_ID/languages', $url);
+
+            return new MockResponse(json_encode(['languages' => []]));
+        };
+
+        $createLanguagesResponse = function (string $method, string $url, array $options = []): ResponseInterface {
+            $expectedBody = json_encode([
+                'languages' => [
+                    ['lang_iso' => 'en'],
+                ],
+            ]);
+
+            $this->assertSame('POST', $method);
+            $this->assertSame('https://api.lokalise.com/api2/projects/PROJECT_ID/languages', $url);
+            $this->assertJsonStringEqualsJsonString($expectedBody, $options['body']);
+
+            return new MockResponse('', ['http_code' => 500]);
+        };
+
+        $provider = $this->createProvider((new MockHttpClient([
+            $getLanguagesResponse,
+            $createLanguagesResponse,
+        ]))->withOptions([
+            'base_uri' => 'https://api.lokalise.com/api2/projects/PROJECT_ID/',
+            'headers' => ['X-Api-Token' => 'API_KEY'],
+        ]), $this->getLoader(), $this->getLogger(), $this->getDefaultLocale(), 'api.lokalise.com');
+
+        $translatorBag = new TranslatorBag();
+        $translatorBag->addCatalogue(new MessageCatalogue('en', [
+            'messages' => ['young_dog' => 'puppy'],
+        ]));
+
+        $this->expectException(ProviderException::class);
+        $this->expectExceptionMessage('Unable to create languages on Lokalise.');
+
+        $provider->write($translatorBag);
+    }
+
+    public function testWriteGetKeysIdsServerError()
+    {
+        $getLanguagesResponse = function (string $method, string $url, array $options = []): ResponseInterface {
+            $this->assertSame('GET', $method);
+            $this->assertSame('https://api.lokalise.com/api2/projects/PROJECT_ID/languages', $url);
+
+            return new MockResponse(json_encode(['languages' => []]));
+        };
+
+        $createLanguagesResponse = function (string $method, string $url, array $options = []): ResponseInterface {
+            $expectedBody = json_encode([
+                'languages' => [
+                    ['lang_iso' => 'en'],
+                ],
+            ]);
+
+            $this->assertSame('POST', $method);
+            $this->assertSame('https://api.lokalise.com/api2/projects/PROJECT_ID/languages', $url);
+            $this->assertJsonStringEqualsJsonString($expectedBody, $options['body']);
+
+            return new MockResponse(json_encode(['keys' => []]));
+        };
+
+        $getKeysIdsForMessagesDomainResponse = function (string $method, string $url, array $options = []): ResponseInterface {
+            $expectedQuery = [
+                'filter_keys' => '',
+                'filter_filenames' => 'messages.xliff',
+                'limit' => 5000,
+                'page' => 1,
+            ];
+
+            $this->assertSame('GET', $method);
+            $this->assertSame('https://api.lokalise.com/api2/projects/PROJECT_ID/keys?'.http_build_query($expectedQuery), $url);
+            $this->assertSame($expectedQuery, $options['query']);
+
+            return new MockResponse('', ['http_code' => 500]);
+        };
+
+        $provider = $this->createProvider((new MockHttpClient([
+            $getLanguagesResponse,
+            $createLanguagesResponse,
+            $getKeysIdsForMessagesDomainResponse,
+        ]))->withOptions([
+            'base_uri' => 'https://api.lokalise.com/api2/projects/PROJECT_ID/',
+            'headers' => ['X-Api-Token' => 'API_KEY'],
+        ]), $this->getLoader(), $this->getLogger(), $this->getDefaultLocale(), 'api.lokalise.com');
+
+        $translatorBag = new TranslatorBag();
+        $translatorBag->addCatalogue(new MessageCatalogue('en', [
+            'messages' => ['young_dog' => 'puppy'],
+        ]));
+
+        $this->expectException(ProviderException::class);
+        $this->expectExceptionMessage('Unable to get keys ids from Lokalise.');
+
+        $provider->write($translatorBag);
+    }
+
+    public function testWriteCreateKeysServerError()
+    {
+        $getLanguagesResponse = function (string $method, string $url, array $options = []): ResponseInterface {
+            $this->assertSame('GET', $method);
+            $this->assertSame('https://api.lokalise.com/api2/projects/PROJECT_ID/languages', $url);
+
+            return new MockResponse(json_encode(['languages' => []]));
+        };
+
+        $createLanguagesResponse = function (string $method, string $url, array $options = []): ResponseInterface {
+            $expectedBody = json_encode([
+                'languages' => [
+                    ['lang_iso' => 'en'],
+                ],
+            ]);
+
+            $this->assertSame('POST', $method);
+            $this->assertSame('https://api.lokalise.com/api2/projects/PROJECT_ID/languages', $url);
+            $this->assertJsonStringEqualsJsonString($expectedBody, $options['body']);
+
+            return new MockResponse(json_encode(['keys' => []]));
+        };
+
+        $getKeysIdsForMessagesDomainResponse = function (string $method, string $url, array $options = []): ResponseInterface {
+            $expectedQuery = [
+                'filter_keys' => '',
+                'filter_filenames' => 'messages.xliff',
+                'limit' => 5000,
+                'page' => 1,
+            ];
+
+            $this->assertSame('GET', $method);
+            $this->assertSame('https://api.lokalise.com/api2/projects/PROJECT_ID/keys?'.http_build_query($expectedQuery), $url);
+            $this->assertSame($expectedQuery, $options['query']);
+
+            return new MockResponse(json_encode(['keys' => []]));
+        };
+
+        $createKeysForMessagesDomainResponse = function (string $method, string $url, array $options = []): ResponseInterface {
+            $expectedBody = json_encode([
+                'keys' => [
+                    [
+                        'key_name' => 'young_dog',
+                        'platforms' => ['web'],
+                        'filenames' => [
+                            'web' => 'messages.xliff',
+                            'ios' => null,
+                            'android' => null,
+                            'other' => null,
+                        ],
+                    ],
+                ],
+            ]);
+
+            $this->assertSame('POST', $method);
+            $this->assertJsonStringEqualsJsonString($expectedBody, $options['body']);
+
+            return new MockResponse('', ['http_code' => 500]);
+        };
+
+        $provider = $this->createProvider((new MockHttpClient([
+            $getLanguagesResponse,
+            $createLanguagesResponse,
+            $getKeysIdsForMessagesDomainResponse,
+            $createKeysForMessagesDomainResponse,
+        ]))->withOptions([
+            'base_uri' => 'https://api.lokalise.com/api2/projects/PROJECT_ID/',
+            'headers' => ['X-Api-Token' => 'API_KEY'],
+        ]), $this->getLoader(), $this->getLogger(), $this->getDefaultLocale(), 'api.lokalise.com');
+
+        $translatorBag = new TranslatorBag();
+        $translatorBag->addCatalogue(new MessageCatalogue('en', [
+            'messages' => ['young_dog' => 'puppy'],
+        ]));
+
+        $this->expectException(ProviderException::class);
+        $this->expectExceptionMessage('Unable to create keys to Lokalise.');
+
+        $provider->write($translatorBag);
+    }
+
+    public function testWriteUploadTranslationsServerError()
+    {
+        $getLanguagesResponse = function (string $method, string $url, array $options = []): ResponseInterface {
+            $this->assertSame('GET', $method);
+            $this->assertSame('https://api.lokalise.com/api2/projects/PROJECT_ID/languages', $url);
+
+            return new MockResponse(json_encode(['languages' => []]));
+        };
+
+        $createLanguagesResponse = function (string $method, string $url, array $options = []): ResponseInterface {
+            $expectedBody = json_encode([
+                'languages' => [
+                    ['lang_iso' => 'en'],
+                ],
+            ]);
+
+            $this->assertSame('POST', $method);
+            $this->assertSame('https://api.lokalise.com/api2/projects/PROJECT_ID/languages', $url);
+            $this->assertJsonStringEqualsJsonString($expectedBody, $options['body']);
+
+            return new MockResponse(json_encode(['keys' => []]));
+        };
+
+        $getKeysIdsForMessagesDomainResponse = function (string $method, string $url, array $options = []): ResponseInterface {
+            $expectedQuery = [
+                'filter_keys' => '',
+                'filter_filenames' => 'messages.xliff',
+                'limit' => 5000,
+                'page' => 1,
+            ];
+
+            $this->assertSame('GET', $method);
+            $this->assertSame('https://api.lokalise.com/api2/projects/PROJECT_ID/keys?'.http_build_query($expectedQuery), $url);
+            $this->assertSame($expectedQuery, $options['query']);
+
+            return new MockResponse(json_encode(['keys' => []]));
+        };
+
+        $createKeysForMessagesDomainResponse = function (string $method, string $url, array $options = []): ResponseInterface {
+            $expectedBody = json_encode([
+                'keys' => [
+                    [
+                        'key_name' => 'young_dog',
+                        'platforms' => ['web'],
+                        'filenames' => [
+                            'web' => 'messages.xliff',
+                            'ios' => null,
+                            'android' => null,
+                            'other' => null,
+                        ],
+                    ],
+                ],
+            ]);
+
+            $this->assertSame('POST', $method);
+            $this->assertJsonStringEqualsJsonString($expectedBody, $options['body']);
+
+            return new MockResponse(json_encode(['keys' => [
+                [
+                    'key_name' => ['web' => 'young_dog'],
+                    'key_id' => 29,
+                ],
+            ]]));
+        };
+
+        $updateTranslationsResponse = function (string $method, string $url, array $options = []) use (&$updateProcessed): ResponseInterface {
+            $this->assertSame('PUT', $method);
+
+            return new MockResponse('', ['http_code' => 500]);
+        };
+
+        $provider = $this->createProvider((new MockHttpClient([
+            $getLanguagesResponse,
+            $createLanguagesResponse,
+            $getKeysIdsForMessagesDomainResponse,
+            $createKeysForMessagesDomainResponse,
+            $updateTranslationsResponse,
+        ]))->withOptions([
+            'base_uri' => 'https://api.lokalise.com/api2/projects/PROJECT_ID/',
+            'headers' => ['X-Api-Token' => 'API_KEY'],
+        ]), $this->getLoader(), $this->getLogger(), $this->getDefaultLocale(), 'api.lokalise.com');
+
+        $translatorBag = new TranslatorBag();
+        $translatorBag->addCatalogue(new MessageCatalogue('en', [
+            'messages' => ['young_dog' => 'puppy'],
+        ]));
+
+        $this->expectException(ProviderException::class);
+        $this->expectExceptionMessage('Unable to create/update translations to Lokalise.');
+
+        $provider->write($translatorBag);
+    }
+
     /**
      * @dataProvider getResponsesForOneLocaleAndOneDomain
      */
@@ -397,10 +699,12 @@ class LokaliseProviderTest extends ProviderTestCase
         $translatorBag->addCatalogue(new MessageCatalogue('en', [
             'messages' => ['a' => 'trans_en_a'],
             'validators' => ['post.num_comments' => '{count, plural, one {# comment} other {# comments}}'],
+            'domain_without_missing_messages' => [],
         ]));
         $translatorBag->addCatalogue(new MessageCatalogue('fr', [
             'messages' => ['a' => 'trans_fr_a'],
             'validators' => ['post.num_comments' => '{count, plural, one {# commentaire} other {# commentaires}}'],
+            'domain_without_missing_messages' => [],
         ]));
 
         $provider = $this->createProvider(
