@@ -33,7 +33,9 @@ class ImageValidatorTest extends ConstraintValidatorTestCase
     protected $imageLandscape;
     protected $imagePortrait;
     protected $image4By3;
+    protected $image16By9;
     protected $imageCorrupted;
+    protected $notAnImage;
 
     protected function createValidator()
     {
@@ -48,7 +50,9 @@ class ImageValidatorTest extends ConstraintValidatorTestCase
         $this->imageLandscape = __DIR__.'/Fixtures/test_landscape.gif';
         $this->imagePortrait = __DIR__.'/Fixtures/test_portrait.gif';
         $this->image4By3 = __DIR__.'/Fixtures/test_4by3.gif';
+        $this->image16By9 = __DIR__.'/Fixtures/test_16by9.gif';
         $this->imageCorrupted = __DIR__.'/Fixtures/test_corrupted.gif';
+        $this->notAnImage = __DIR__.'/Fixtures/ccc.txt';
     }
 
     public function testNullIsValid()
@@ -413,6 +417,28 @@ class ImageValidatorTest extends ConstraintValidatorTestCase
         $this->assertNoViolation();
     }
 
+    public function testMinRatioUsesInputMoreDecimals()
+    {
+        $constraint = new Image([
+            'minRatio' => 4 / 3,
+        ]);
+
+        $this->validator->validate($this->image4By3, $constraint);
+
+        $this->assertNoViolation();
+    }
+
+    public function testMaxRatioUsesInputMoreDecimals()
+    {
+        $constraint = new Image([
+            'maxRatio' => 16 / 9,
+        ]);
+
+        $this->validator->validate($this->image16By9, $constraint);
+
+        $this->assertNoViolation();
+    }
+
     public function testInvalidMinRatio()
     {
         $this->expectException(ConstraintDefinitionException::class);
@@ -537,6 +563,21 @@ class ImageValidatorTest extends ConstraintValidatorTestCase
             ->assertRaised();
     }
 
+    public function testInvalidMimeType()
+    {
+        $this->validator->validate($this->notAnImage, $constraint = new Image());
+
+        $this->assertSame('image/*', $constraint->mimeTypes);
+
+        $this->buildViolation('This file is not a valid image.')
+            ->setParameter('{{ file }}', sprintf('"%s"', $this->notAnImage))
+            ->setParameter('{{ type }}', '"text/plain"')
+            ->setParameter('{{ types }}', '"image/*"')
+            ->setParameter('{{ name }}', '"ccc.txt"')
+            ->setCode(Image::INVALID_MIME_TYPE_ERROR)
+            ->assertRaised();
+    }
+
     public function provideDetectCorruptedConstraints(): iterable
     {
         yield 'Doctrine style' => [new Image([
